function in_data = fem_input

% fem_input.m - input file for FEM analysis  

% 2-D Navier-Stokes flow problem. Two 3-node constant gradiant triangular elements 

% Control Data: [   nodes            % Total number of nodes
%                   numel            % Total number of elements
%                   nodaldof         % Max dof per node
%                   nodesperelement  % Max nodes per element
%                   numat            % Max mumber of materials
%                   ndimensions      % Number of space dimensions  ]

in_data.control = [6 4 3 3 2 2 ];

% Nodal Data: [ node# x1 x2 x3] 
in_data.ND = [   
   1   0   0;
   2   2   0;
   3   0   2;
   4   2   2;
   5   0   4;
   6   2   4];
   
% Material Property Data: [ 
%                      Element type for material no. 1
%                      Element parameter 1 (Fluid density)
%                      Element parameter 2 (Fluid viscosity)
%                      Element parameter 3 
%                      Element parameter 4
%                      Element parameter 5
 in_data.mater = [23 1 1 0 0 0;
                  23 1 1 0 0 0];                   

% Element Association Data: [ element# materialtype# node1# node2# ....] 
in_data.EL = [  
   1   1   1   2   4;
   2   1   1   4   3;
   3   1   3   4   6;
   4   1   3   6   5]; 
   
% Nodal Constraint Data: [ node# velocity_1 velocity_2 pressure ] 
% 1 = fixed bc; 0 = non-fixed bc
in_data.CON = [  
   1   1  1  1;
   2   1  1  1;
   3   0  0  1;
   4   0  0  1;
   5   0  1  1;
   6   0  1  1];

% Nodal Load Data: [node# velocity_1 velocity_2 pressure] 
% Magnitude of prescribed bc defined in CON
in_data.LOAD = [ 
   1   0  0  1;
   2   0  0  0;
   3   0  0  1;
   4   0  0  0;
   5   0  0  1;
   6   0  0  0];

 